# Author: Robert Luke <mail@robertluke.net>
#
# License: BSD (3-clause)

from ._snirf import write_raw_snirf, SPEC_FORMAT_VERSION
